@@ -50,6 +50,7 @@ public class Wdic2Xml {
     private static final String _PROGRAM = Wdic2Xml.class.getName();
 
     private static final String ENCODING = "UTF-8";
+    private static final String WDIC_GLYPH_DIR = "glyph";
     private static final String WDIC_PLUGIN_DIR = "plugin";
     private static final String WDIC_GAIJI_DIR = "gaiji";
     private static final String WDIC_TABLE_DIR = "table";
@@ -74,6 +75,8 @@ public class Wdic2Xml {
     private Map<String,Set<WdicItem>> _pluginMap = null;
     /** 外字マップ */
     private Map<String,String> _gaijiMap = null;
+    /** グリフリスト */
+    private List<String> _glyphList = null;
     /** 表リスト */
     private List<String> _tableList = null;
 
@@ -128,6 +131,7 @@ public class Wdic2Xml {
         _manual = new WdicMan(file);
         _pluginMap = _groupList.getPluginMap();
         _gaijiMap = new TreeMap<String,String>();
+        _glyphList = new ArrayList<String>();
         _tableList = new ArrayList<String>();
 
         DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
@@ -183,8 +187,21 @@ public class Wdic2Xml {
             }
         }
 
+        File glyph = new File(_basedir, WDIC_GLYPH_DIR);
+        int len = _glyphList.size();
+        for (int i=0; i<len; i++) {
+            String name = _glyphList.get(i);
+            String bmpName = name + ".50px.png.bmp";
+            File bmp = new File(glyph, bmpName);
+            if (!bmp.exists()) {
+                _log.error("file not found: " + bmp.getPath());
+            }
+            String path = FilenameUtils.concat(WDIC_GLYPH_DIR, bmpName);
+            _appendData(graphic, "glyph-"+name, path, "bmp");
+        }
+
         File table = new File(_basedir, WDIC_TABLE_DIR);
-        int len = _tableList.size();
+        len = _tableList.size();
         for (int i=0; i<len; i++) {
             String name = _tableList.get(i) + ".bmp";
             File bmp = new File(table, name);
@@ -1351,8 +1368,13 @@ public class Wdic2Xml {
             if (item.isAlias()) {
                 String name = item.getHead();
                 _appendRawText(layerElem, name);
-                String yomi = item.getYomi().get(0);
-                _appendText(item, layerElem, " [" + yomi + "]");
+                List<String> yomiList = item.getYomi();
+                if (yomiList.isEmpty()) {
+                    _log.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
+                } else {
+                    String yomi = yomiList.get(0);
+                    _appendText(item, layerElem, " [" + yomi + "]");
+                }
                 _appendRawText(layerElem, " \u21d2 ");
                 name = item.getRealName();
                 String refid = WdicUtil.unescape(name);
@@ -1365,8 +1387,13 @@ public class Wdic2Xml {
                 id ="WDIC:" + grpId + ":" + name;
                 refElem = _appendIdReference(layerElem, id);
                 _appendRawText(refElem, name);
-                String yomi = item.getYomi().get(0);
-                _appendText(item, layerElem, " [" + yomi + "]");
+                List<String> yomiList = item.getYomi();
+                if (yomiList.isEmpty()) {
+                    _log.info("yomi not defined: " + grpId + ":" + partId + ":" + item.getHead());
+                } else {
+                    String yomi = yomiList.get(0);
+                    _appendText(item, layerElem, " [" + yomi + "]");
+                }
                 _appendNewLine(layerElem);
             }
         }
@@ -1945,6 +1972,15 @@ public class Wdic2Xml {
                 // ignore
             } else if ("mex".equals(name)) {
                 buf.append("[" + param.get(0) + "]");
+            } else if ("glyph".equals(name)) {
+                _appendRawText(node, buf.toString());
+                buf.delete(0, buf.length());
+                String glyph = param.get(0);
+                if (!_glyphList.contains(glyph)) {
+                    _glyphList.add(glyph);
+                }
+                Element elem = _appendDataReference(node, "glyph-"+glyph, "inlineGraphic");
+                _appendRawText(elem, "[グリフ:" + glyph + "]");
             } else if ("oline".equals(name)) {
                 _appendRawText(node, buf.toString());
                 buf.delete(0, buf.length());
@@ -2047,9 +2083,26 @@ public class Wdic2Xml {
                     }
                     _appendCharReference(node, fontname, type);
                 }
+            } else if ("date".equals(name) || "dt".equals(name)) {
+                _appendRawText(node, buf.toString());
+                buf.delete(0, buf.length());
+                buf.append(param.get(0));
+//                 if (param.size() > 1) {
+//                     String type = param.get(1);
+//                     if ("JC".equals(type)) {
+//                         buf.append("[ユリウス歴]");
+//                     } else if ("GC".equals(type)) {
+//                         buf.append("[グレゴリオ歴]");
+//                     } else if ("LC".equals(type)) {
+//                         buf.append("[太陰太陽歴]");
+//                     } else {
+//                         _log.error("unknown function parameter: " + itemId + " [" + name + ":" + type + "]");
+//                     }
+//                 }
+                _appendText(item, node, buf.toString(), linkBlock);
+                buf.delete(0, buf.length());
             } else {
-                if (!"unit".equals(name)
-                    && !"date".equals(name) && !"dt".equals(name)) {
+                if (!"unit".equals(name)) {
                     _log.error("unknown function name: " + itemId + " [" + name + "]");
                 }
                 _appendRawText(node, buf.toString());
@@ -2126,9 +2179,15 @@ public class Wdic2Xml {
                                      FileFilterUtils.prefixFileFilter(name),
                                      FileFilterUtils.suffixFileFilter(".xbm")));
                     if (ArrayUtils.isEmpty(files)) {
-                        _log.info("unsupported characters:"
-                                  + " '" + s + "'"
-                                  + " " + unicodeBlock.toString());
+                        if (unicodeBlock == null) {
+                            _log.info("unsupported characters:"
+                                      + " '" + s + "'"
+                                      + " UNKNOWN_UNICODE_BLOCK");
+                        } else {
+                            _log.info("unsupported characters:"
+                                      + " '" + s + "'"
+                                      + " " + unicodeBlock.toString());
+                        }
                         BufferedImage img = WdicUtil.toImage(s);
                         int height = img.getHeight();
                         int width = 8;
@@ -2164,10 +2223,16 @@ public class Wdic2Xml {
                     File file = new File(dir, name + ".xbm");
                     if (!file.exists()) {
                         String s = String.valueOf(Character.toChars(codePoint));
-                        _log.info("unsupported character:"
-                                  + " [U+" + hex + "]"
-                                  + " '" + s + "'"
-                                  + " " + unicodeBlock.toString());
+                        if (unicodeBlock == null) {
+                            _log.info("unsupported characters:"
+                                      + " '" + s + "'"
+                                      + " UNKNOWN_UNICODE_BLOCK");
+                        } else {
+                            _log.info("unsupported character:"
+                                      + " [U+" + hex + "]"
+                                      + " '" + s + "'"
+                                      + " " + unicodeBlock.toString());
+                        }
                         BufferedImage img = WdicUtil.toImage(codePoint);
                         try {
                             FontUtil.writeXbm(img, file);
