@@ -276,16 +276,28 @@ public class WdicTable {
      */
     private List<WdicTableRow> _parse() {
         List<WdicTableRow> rowList = null;
-        if (_list.isEmpty()) {
-            rowList = new ArrayList<WdicTableRow>();
-        } else {
-            String str = _list.get(0);
-            if (str.startsWith("| ")) {
-                rowList = _parseFullSpec();
-            } else {
-                rowList = _parseSimple();
+        if (!_list.isEmpty()) {
+            try {
+                String str = _list.get(0);
+                if (str.startsWith("| ")) {
+                    rowList = _parseFullSpec();
+                } else {
+                    rowList = _parseSimple();
+                }
+            } catch (Exception e) {
+                String sep = System.getProperty("line.separator", "\n");
+                StringBuilder buf = new StringBuilder();
+                int len = _list.size();
+                for (int i=0; i<len; i++) {
+                    buf.append(_list.get(i));
+                    buf.append(sep);
+                }
+                _log.warn("unexpect table format: " + _id + sep + buf.toString(), e);
             }
         }
+        if (rowList == null) {
+            rowList = new ArrayList<WdicTableRow>();
+        }
         return rowList;
     }
 
