@@ -755,12 +755,21 @@ public class WdicTableItem {
                     } else if (font.isItalic()) {
                         style = "ITALIC";
                     }
-                    _log.warn("unavailable display font: [" + code + "]"
-                              + " block:" + unicodeBlock.toString()
-                              + " font:" + font.getName()
-                              + " style:" + style
-                              + " size:" + font.getSize()
-                              + " (using plain font)");
+                    if (unicodeBlock == null) {
+                        _log.warn("unavailable display font: [" + code + "]"
+                                  + " block:UNKNOWN_UNICODE_BLOCK"
+                                  + " font:" + font.getName()
+                                  + " style:" + style
+                                  + " size:" + font.getSize()
+                                  + " (using plain font)");
+                    } else {
+                        _log.warn("unavailable display font: [" + code + "]"
+                                  + " block:" + unicodeBlock.toString()
+                                  + " font:" + font.getName()
+                                  + " style:" + style
+                                  + " size:" + font.getSize()
+                                  + " (using plain font)");
+                    }
                     font = plainFont;
                 }
             }
@@ -786,8 +795,13 @@ public class WdicTableItem {
                 } else {
                     // 表示できない文字は'?'を描画
                     String code = "U+" + HexUtil.toHexString(codePoint, 6);
-                    _log.warn("unavailable display font: [" + code + "]"
-                              + " " + unicodeBlock.toString());
+                    if (unicodeBlock == null) {
+                        _log.warn("unavailable display font: [" + code + "]"
+                                  + " UNKNOWN_UNICODE_BLOCK");
+                    } else {
+                        _log.warn("unavailable display font: [" + code + "]"
+                                  + " " + unicodeBlock.toString());
+                    }
                     codePoint = '?';
                     drawStr = String.valueOf(Character.toChars(codePoint));
                     font = WdicUtil.getFont(codePoint);
