@@ -471,8 +471,13 @@ public class WdicUtil {
             } else {
                 // 表示できない文字は'?'を描画
                 String code = "U+" + HexUtil.toHexString(codePoint, 6);
-                _log.warn("unavailable display font: [" + code + "]"
-                          + " " + unicodeBlock.toString());
+                if (unicodeBlock == null) {
+                    _log.warn("unavailable display font: [" + code + "]"
+                              + " UNKNOWN_UNICODE_BLOCK");
+                } else {
+                    _log.warn("unavailable display font: [" + code + "]"
+                              + " " + unicodeBlock.toString());
+                }
                 codePoint = '?';
                 font = getFont(codePoint);
                 if ("narrow".equals(type)) {
@@ -573,8 +578,13 @@ public class WdicUtil {
         }
 
         String code = "U+" + HexUtil.toHexString(codePoint, 6);
-        _log.info("undefined font: [" + code + "]"
-                  + " " + unicodeBlock.toString());
+        if (unicodeBlock == null) {
+            _log.info("undefined font: [" + code + "]"
+                      + " UNKNOWN_UNICODE_BLOCK");
+        } else {
+            _log.info("undefined font: [" + code + "]"
+                      + " " + unicodeBlock.toString());
+        }
 
         // デフォルトフォントから検索
         len = ArrayUtils.getLength(DEFAULT_FONT);
