@@ -40,7 +40,7 @@ public class SingleWordSearcher implements Searcher {
     private static final int FIXED = 1;
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
 
     /** 副本 */
     private SubBook _sub = null;
@@ -399,6 +399,7 @@ public class SingleWordSearcher implements Searcher {
      * @return 検索結果 (次の検索結果がない場合null)
      * @exception EBException 検索中にエラーが発生した場合
      */
+    @Override
     public Result getNextResult() throws EBException {
         if (_comparison < 0) {
             return null;
@@ -634,18 +635,18 @@ public class SingleWordSearcher implements Searcher {
         return false;
     }
 
-    /**
-     * 指定されたページが階層開始ページかどうかを判別します。
-     *
-     * @param id ページID
-     * @return 階層開始ページである場合はtrue、そうでない場合はfalse
-     */
-    private boolean _isLayerStart(int id) {
-        if ((id & 0x40) == 0x40) {
-            return true;
-        }
-        return false;
-    }
+//     /**
+//      * 指定されたページが階層開始ページかどうかを判別します。
+//      *
+//      * @param id ページID
+//      * @return 階層開始ページである場合はtrue、そうでない場合はfalse
+//      */
+//     private boolean _isLayerStart(int id) {
+//         if ((id & 0x40) == 0x40) {
+//             return true;
+//         }
+//         return false;
+//     }
 
     /**
      * 指定されたページが階層終了ページかどうかを判別します。
