@@ -212,7 +212,6 @@ public class EBZip implements EBZipConstants {
             System.exit(0);
         }
 
-        String path = null;
         String[] paths = cmd.getArgs();
         int len = ArrayUtils.getLength(paths);
         switch (len) {
@@ -426,10 +425,8 @@ public class EBZip implements EBZipConstants {
             return;
         }
 
-        if (!_test) {
-            if (!_isOverwrite(f)) {
-                return;
-            }
+        if (!_test && !_isOverwrite(f)) {
+            return;
         }
 
         BookInputStream bis = null;
@@ -700,10 +697,8 @@ public class EBZip implements EBZipConstants {
             return;
         }
 
-        if (!_test) {
-            if (!_isOverwrite(f)) {
-                return;
-            }
+        if (!_test && !_isOverwrite(f)) {
+            return;
         }
 
         BookInputStream bis = null;
