@@ -1,7 +1,6 @@
 package fuku.xml2eb;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 
 import fuku.eb4j.util.HexUtil;
 
@@ -34,6 +33,7 @@ public class InvalidCharacterException extends IOException {
      *
      * @return 詳細メッセージ文字列
      */
+    @Override
     public String getMessage() {
         return _msg;
     }
