@@ -38,7 +38,7 @@ public class Linker {
     private static final int SOUND = 8;
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
     /** 出力ファイル */
     private File _outfile = null;
     /** 入力ファイル */
