@@ -36,8 +36,9 @@ public class TextOutputStream extends BlockOutputStream {
     private static final Integer DECORATION = Integer.valueOf(5);
     private static final Integer KEYWORD = Integer.valueOf(6);
     private static final Integer REFERENCE = Integer.valueOf(7);
-    private static final Integer CGRAPHIC = Integer.valueOf(8);
-    private static final Integer SOUND = Integer.valueOf(9);
+    private static final Integer ICGRAPHIC = Integer.valueOf(8);
+    private static final Integer CGRAPHIC = Integer.valueOf(9);
+    private static final Integer SOUND = Integer.valueOf(10);
 
     /** ログ */
     private Log _log = null;
@@ -584,6 +585,56 @@ public class TextOutputStream extends BlockOutputStream {
         _stack.pop();
     }
 
+    /**
+     * インラインカラー画像の参照を開始します。
+     *
+     * @param name 画像参照名称
+     * @param format 画像フォーマット
+     * @exception IOException 入出力エラーが発生した場合
+     */
+    public void beginInlineColorGraphic(String name, String format) throws IOException {
+        if (_isModifier(NARROW)) {
+            endNarrow();
+        }
+        if (_stack.search(ICGRAPHIC) > 0) {
+            throw new IOException("duplicate modifier");
+        }
+        write(0x1f);
+        write(0x3c);
+        if ("bmp".equals(format)) {
+            write(0x00);
+            write(0x09);
+        } else {
+            write(0x12);
+            write(0x09);
+        }
+        write(0x00);
+        write(0x01);
+        byte[] b = new byte[14];
+        Arrays.fill(b, (byte)0x00);
+        write(b, 0, b.length);
+        _ref.putGraphicRef(_file, getSize()-6, name);
+        _stack.push(ICGRAPHIC);
+    }
+
+    /**
+     * インラインカラー画像の参照を終了します。
+     *
+     * @exception IOException 入出力エラーが発生した場合
+     */
+    public void endInlineColorGraphic() throws IOException {
+        if (_isModifier(NARROW)) {
+            endNarrow();
+        }
+        if (!_isModifier(ICGRAPHIC)) {
+            throw new IOException("unexpected the end of modifier");
+        }
+        write(0x1f);
+        write(0x5c);
+        _stack.pop();
+    }
+
+
     /**
      * カラー画像の参照を開始します。
      *
@@ -604,7 +655,7 @@ public class TextOutputStream extends BlockOutputStream {
             write(0x00);
             write(0x09);
         } else {
-            write(0x10);
+            write(0x12);
             write(0x09);
         }
         write(0x00);
