@@ -726,7 +726,12 @@ public class Xml2Eb {
                 } else if (e.hasAttribute("data")) {
                     String data = e.getAttribute("data");
                     String type = e.getAttribute("type");
-                    if ("graphic".equals(type)) {
+                    if ("inlineGraphic".equals(type)) {
+                        if (ref.hasGraphicTag(data)) {
+                            String format = ref.getGraphicFormat(data);
+                            stream.beginInlineColorGraphic(data, format);
+                        }
+                    } else if ("graphic".equals(type)) {
                         if (ref.hasGraphicTag(data)) {
                             String format = ref.getGraphicFormat(data);
                             stream.beginColorGraphic(data, format);
@@ -774,7 +779,11 @@ public class Xml2Eb {
                 } else if (e.hasAttribute("data")) {
                     String data = e.getAttribute("data");
                     String type = e.getAttribute("type");
-                    if ("graphic".equals(type)) {
+                    if ("inlineGraphic".equals(type)) {
+                        if (ref.hasGraphicTag(data)) {
+                            stream.endInlineColorGraphic();
+                        }
+                    } else if ("graphic".equals(type)) {
                         if (ref.hasGraphicTag(data)) {
                             stream.endColorGraphic();
                         }
