@@ -167,10 +167,17 @@ public class FontUtil {
         int x = (width - w) / 2;
         int y = height - h + fm.getAscent();
 
-        _log.debug("display font: [" + code + "]"
-                   + " block:" + unicodeBlock.toString()
-                   + " font:" + font.getName()
-                   + " size:" + font.getSize());
+        if (unicodeBlock == null) {
+            _log.debug("display font: [" + code + "]"
+                       + " block:UNKNOWN_UNICODE_BLOCK"
+                       + " font:" + font.getName()
+                       + " size:" + font.getSize());
+        } else {
+            _log.debug("display font: [" + code + "]"
+                       + " block:" + unicodeBlock.toString()
+                       + " font:" + font.getName()
+                       + " size:" + font.getSize());
+        }
         g2.setFont(font);
         g2.setColor(Color.BLACK);
         g2.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING,
